@@ -1,17 +1,10 @@
-VERSION = (1,0,6)
-__version__ = "1.0.6"
+VERSION = (1,0,7)
+__version__ = "1.0.7"
 import random 
 import os
 
-try:
-    from django.conf import settings
-    from django.contrib.sites.models import Site
-    from cms.conf.patch import post_patch
-except:
-    pass
-    
 def init_themes():
-
+    print 'Initing themes'
     if not hasattr(settings, 'THEMES_DIR'):
         THEMES_DIR = os.path.join(settings.PROJECT_DIR, 'themes')
         if not os.path.exists(THEMES_DIR):
@@ -28,11 +21,18 @@ def init_themes():
         setattr(settings, 'DEFAULT_TEMPLATE_DIRS', settings.TEMPLATE_DIRS)
     
 def set_themes():
+    print 'Setting themes...'
     if not Site.objects.filter(id=settings.SITE_ID):
         return
 
     site = Site.objects.get(id=settings.SITE_ID)
-    themes = [theme.name for theme in site.theme_set.all()]
+    themes = None
+
+    if hasattr(site, 'theme_set'):
+        try:
+            themes = [theme.name for theme in site.theme_set.all()]
+        except:
+            pass
 
     if not themes: 
         return
@@ -51,7 +51,12 @@ def set_themes():
     setattr(settings, 'CMS_TEMPLATES', tuple(theme_templates) + settings.DEFAULT_CMS_TEMPLATES)
 
 try:
+    from django.conf import settings
+    from django.contrib.sites.models import Site
+    from cms.conf.patch import post_patch
+
     init_themes()
     set_themes()
-except ImportError:
-    pass
+except Exception as ex:
+    print ex
+
